summaryrefslogtreecommitdiffstats
path: root/jjb/fuel/fuel-download-artifact.sh
diff options
context:
space:
mode:
Diffstat (limited to 'jjb/fuel/fuel-download-artifact.sh')
-rwxr-xr-xjjb/fuel/fuel-download-artifact.sh16
1 files changed, 15 insertions, 1 deletions
diff --git a/jjb/fuel/fuel-download-artifact.sh b/jjb/fuel/fuel-download-artifact.sh
index 917bc97a0..a1a1de47e 100755
--- a/jjb/fuel/fuel-download-artifact.sh
+++ b/jjb/fuel/fuel-download-artifact.sh
@@ -16,9 +16,23 @@ fi
# check if we got the file
[[ -f latest.properties ]] || exit 1
# source the file so we get OPNFV vars
source latest.properties
+# echo the info about artifact that is used during the deployment
+OPNFV_ARTIFACT=${OPNFV_ARTIFACT_URL/*\/}
+echo "Using $OPNFV_ARTIFACT for deployment"
+
+# check if we already have the ISO to avoid redownload
+# disabled for the timebeing - needs adjustments
+#ISO_STORE=$HOME/opnfv/iso_store/fuel
+#if [[ -f "$ISO_STORE/$OPNFV_ARTIFACT" ]]; then
+# echo "ISO already exists. Skipping the download"
+# ln -s $ISO_STORE/$OPNFV_ARTIFACT $WORKSPACE/opnfv.iso
+# ls -al $WORKSPACE/opnfv.iso
+# exit 0
+#fi
+
# log info to console
echo "Downloading the $INSTALLER_TYPE artifact using URL http://$OPNFV_ARTIFACT_URL"
echo "This could take some time..."
@@ -16,9 +16,23 @@ fi
# check if we got the file
[[ -f latest.properties ]] || exit 1
-# source the file so we get OPNFV vars
+# source the file so we get artifact metadata
source latest.properties